// Copyright 2012 Intel Corporation
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// - Redistributions of source code must retain the above copyright notice, this
//   list of conditions and the following disclaimer.
//
// - Redistributions in binary form must reproduce the above copyright notice,
//   this list of conditions and the following disclaimer in the documentation
//   and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#pragma once

#include <stdbool.h>
#include <stdlib.h>

#undef linux

#include "waffle_wayland.h"

#include "wegl_platform.h"
#include "wcore_util.h"

struct linux_platform;
struct wl_egl_window;
struct wl_surface;

struct wayland_platform {
    struct wegl_platform wegl;
    struct linux_platform *linux;


    void *dl_wl_egl;

    struct wl_egl_window *
    (*wl_egl_window_create)(struct wl_surface *surface,
                            int width, int height);

    void
    (*wl_egl_window_destroy)(struct wl_egl_window *egl_window);

    void
    (*wl_egl_window_resize)(struct wl_egl_window *egl_window,
                            int width, int height,
                            int dx, int dy);

};

DEFINE_CONTAINER_CAST_FUNC(wayland_platform,
                           struct wayland_platform,
                           struct wegl_platform,
                           wegl)

struct wcore_platform*
wayland_platform_create(void);
